{
    "$graph": [
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": "string",
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "string",
                    "id": "#fp_filter.cwl/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/normalize_variants/normalized_vcf",
                            "id": "#fp_filter.cwl/decompose_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/decompose_variants/decomposed_vcf"
                    ],
                    "id": "#fp_filter.cwl/decompose_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_filter/filtered_vcf",
                            "id": "#fp_filter.cwl/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#fp_filter.cwl/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl_2",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/bam",
                            "id": "#fp_filter.cwl/fp_filter/bam"
                        },
                        {
                            "source": "#fp_filter.cwl/min_var_freq",
                            "id": "#fp_filter.cwl/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#fp_filter.cwl/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/fp_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/sample_name",
                            "id": "#fp_filter.cwl/fp_filter/sample_name"
                        },
                        {
                            "source": "#fp_filter.cwl/index/indexed_vcf",
                            "id": "#fp_filter.cwl/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_bgzip/bgzipped_file",
                            "id": "#fp_filter.cwl/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#fp_filter.cwl/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#fp_filter.cwl/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/hard_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/fp_index/indexed_vcf",
                            "id": "#fp_filter.cwl/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/hard_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/hard_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/decompose_variants/decomposed_vcf",
                            "id": "#fp_filter.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/index"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/normalize_variants/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/vcf",
                            "id": "#fp_filter.cwl/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/normalize_variants/normalized_vcf"
                    ],
                    "id": "#fp_filter.cwl/normalize_variants"
                }
            ],
            "id": "#fp_filter.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/unfiltered_vcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "mutect parallel workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "int",
                    "id": "#main/scatter_count"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/filter/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter/reference"
                        },
                        {
                            "valueFrom": "mutect",
                            "id": "#main/filter/variant_caller"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter/unfiltered_vcf",
                        "#main/filter/filtered_vcf"
                    ],
                    "id": "#main/filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#merge_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/mutect/vcf",
                            "id": "#main/merge/vcfs"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_vcf"
                    ],
                    "id": "#main/merge"
                },
                {
                    "scatter": "#main/mutect/interval_list",
                    "run": "#mutect.cwl",
                    "in": [
                        {
                            "source": "#main/split_interval_list/split_interval_lists",
                            "id": "#main/mutect/interval_list"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/mutect/normal_bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/mutect/reference"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/mutect/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/mutect/vcf"
                    ],
                    "id": "#main/mutect"
                },
                {
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#main/interval_list",
                            "id": "#main/split_interval_list/interval_list"
                        },
                        {
                            "source": "#main/scatter_count",
                            "id": "#main/split_interval_list/scatter_count"
                        }
                    ],
                    "out": [
                        "#main/split_interval_list/split_interval_lists"
                    ],
                    "id": "#main/split_interval_list"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/fp_filter-cwl:1.0.1"
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl_2/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl_2/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl_2/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl_2/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf merge",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "concat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "--allow-overlaps",
                "--remove-duplicates",
                "--output-type",
                "z",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.merged_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#merge_vcf.cwl/merged_vcf_basename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#merge_vcf.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "id": "#merge_vcf.cwl/merged_vcf"
                }
            ],
            "id": "#merge_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mutect2 (GATK 4)",
            "baseCommand": [
                "/bin/bash",
                "Mutect2.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000,
                    "tmpdirMin": 100000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.2.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "Mutect2.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\nTUMOR=`(samtools view -H $3 | grep \"^@RG\" | sed \"s/.*SM:\\([^\\t]*\\).*/\\1/g\" | head -n 1)` #Extracting the sample name from the TUMOR bam.\nNORMAL=`(samtools view -H $4 | grep \"^@RG\" | sed \"s/.*SM:\\([^\\t]*\\).*/\\1/g\" | head -n 1)` #Extracting the sample name from the NORMAL bam.\n/gatk/gatk Mutect2 -O $1 -R $2 -I $3 -tumor $TUMOR -I $4 -normal $NORMAL -L $5 #Running Mutect2.\ngunzip mutect.vcf.gz #Unzipping the Mutect2 output vcf file to alter the header names.\ngrep \"^##\" mutect.vcf >mutect.final.vcf #Extracting all the lines above #CHROM in the vcf to a new output vcf.\ngrep \"^#CHROM\" mutect.vcf | sed \"s/\\t$TUMOR\\t/\\tTUMOR\\t/g; s/\\t$NORMAL/\\tNORMAL/g\" >> mutect.final.vcf #Concatenating the #CHROM line with substituted sample headers to the output vcf.\ngrep -v \"^#\" mutect.vcf >> mutect.final.vcf #Concatenating the sites to the output vcf.\nbgzip mutect.final.vcf #Bzipping the final output vcf.\ntabix mutect.final.vcf.gz #Indexing the bzipped output vcf.\nmv mutect.vcf.gz.stats mutect.final.vcf.gz.stats #Renaming the .stats file to match the name conversion of the final output vcf.\n/gatk/gatk FilterMutectCalls -R $2 -V mutect.final.vcf.gz -O mutect.final.filtered.vcf.gz #Running FilterMutectCalls on the output vcf.\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "valueFrom": "mutect.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mutect.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#mutect.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mutect.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mutect.final.filtered.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#mutect.cwl/vcf"
                }
            ],
            "id": "#mutect.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/split_interval_list_helper.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#split_interval_list.cwl/interval_list"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "SCATTER_COUNT=",
                        "separate": false,
                        "position": 2
                    },
                    "id": "#split_interval_list.cwl/scatter_count"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.interval_list"
                    },
                    "id": "#split_interval_list.cwl/split_interval_lists"
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run vt decompose",
            "baseCommand": [
                "vt",
                "decompose"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/vt:0.57721--hf74b74d_1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-s",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/decomposed.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vt_decompose.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "decomposed.vcf.gz"
                    },
                    "id": "#vt_decompose.cwl/decomposed_vcf"
                }
            ],
            "id": "#vt_decompose.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
